;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ado-mode" "20250719.1831"
  "Major mode for editing Stata-related files."
  '((emacs "25.1"))
  :url "https://github.com/louabill/ado-mode"
  :commit "d03e2aab90cce83485b095297921ba0e24f43c69"
  :revdesc "d03e2aab90cc"
  :keywords '("tools" "languages" "files" "convenience" "stata" "mata" "ado")
  :authors '(("Bill Rising" . "brising@alum.mit.edu"))
  :maintainers '(("Bill Rising" . "brising@alum.mit.edu")))
